==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/zh_CN.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Successfully saved" : "保存成功",
    "Saving failed:" : "保存失败:",
    "File mime type" : "文件MIME类型",
    "is" : "是",
    "is not" : "不是",
    "matches" : "匹配",
    "does not match" : "不匹配",
    "Example: {placeholder}" : "例子: {placeholder}",
    "File size (upload)" : "文件大小 (上传)",
    "less" : "小于",
    "less or equals" : "小于等于",
    "greater or equals" : "大于等于",
    "greater" : "大于",
    "File system tag" : "文件系统标签",
    "is tagged with" : "标记为",
    "is not tagged with" : "未标记为",
    "Select tag…" : "选择标签...",
    "Request remote address" : "要求远程地址",
    "matches IPv4" : "匹配 IPv4",
    "does not match IPv4" : "不匹配IPv4",
    "matches IPv6" : "匹配IPv6",
    "does not match IPv6" : "不匹配IPv6",
    "Request time" : "请求时间",
    "between" : "之间",
    "not between" : "不在之间",
    "Start" : "开始",
    "End" : "结束",
    "Select timezone…" : "选择时区",
    "Request URL" : "请求URL",
    "Predefined URLs" : "预定义URL",
    "Files WebDAV" : "文件WebDAV",
    "Request user agent" : "请求用户代理",
    "Sync clients" : "同步客户端",
    "Android client" : "Android 客户端",
    "iOS client" : "iOS 客户端",
    "Desktop client" : "桌面客户端",
    "User group membership" : "用户组成员资格",
    "is member of" : "是成员",
    "is not member of" : "不是成员",
    "The given operator is invalid" : "给定的运算符无效",
    "The given regular expression is invalid" : "给定的正则表达式无效",
    "The given file size is invalid" : "给定的文件大小无效",
    "The given tag id is invalid" : "给定的标签ID无效",
    "The given IP range is invalid" : "给定的IP范围无效",
    "The given end time is invalid" : "输入的截止时间无效",
    "The given group does not exist" : "输入的群组不存在",
    "Operation #%s does not exist" : "操作 %s 不存在",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 %s 无效",
    "Workflow" : "数据流",
    "Add rule group" : "添加规则组",
    "Add rule" : "添加规则",
    "Reset" : "重置",
    "Save" : "保存",
    "Saving…" : "保存中...",
    "Loading…" : "加载中"
},
"nplurals=1; plural=0;");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/zh_CN.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saving failed:" : "保存失败:",
    "is" : "是",
    "is not" : "不是",
    "matches" : "匹配",
    "does not match" : "不匹配",
    "Example: {placeholder}" : "例子: {placeholder}",
    "File size (upload)" : "文件大小 (上传)",
    "less" : "小于",
    "less or equals" : "小于等于",
    "greater or equals" : "大于等于",
    "greater" : "大于",
    "File system tag" : "文件系统标签",
    "is tagged with" : "标记为",
    "is not tagged with" : "未标记为",
    "Select tag…" : "选择标签...",
    "Request remote address" : "要求远程地址",
    "matches IPv4" : "匹配 IPv4",
    "does not match IPv4" : "不匹配IPv4",
    "matches IPv6" : "匹配IPv6",
    "does not match IPv6" : "不匹配IPv6",
    "Request time" : "请求时间",
    "between" : "之间",
    "not between" : "不在之间",
    "Start" : "开始",
    "End" : "结束",
    "Select timezone…" : "选择时区",
    "Request URL" : "请求URL",
    "Predefined URLs" : "预定义URL",
    "Files WebDAV" : "文件WebDAV",
    "Request user agent" : "请求用户代理",
    "Sync clients" : "同步客户端",
    "Android client" : "Android 客户端",
    "iOS client" : "iOS 客户端",
    "Desktop client" : "桌面客户端",
    "User group membership" : "用户组成员资格",
    "is member of" : "是成员",
    "is not member of" : "不是成员",
    "The given operator is invalid" : "给定的运算符无效",
    "The given regular expression is invalid" : "给定的正则表达式无效",
    "The given file size is invalid" : "给定的文件大小无效",
    "The given tag id is invalid" : "给定的标签ID无效",
    "The given IP range is invalid" : "给定的IP范围无效",
    "The given IP range is not valid for IPv4" : "填写的IP范围不是有效的IPv4格式",
    "The given IP range is not valid for IPv6" : "填写的IP范围不是有效的IPv6格式",
    "The given time span is invalid" : "给定的时间范围无效",
    "The given start time is invalid" : "给定的开始时间无效",
    "The given end time is invalid" : "输入的截止时间无效",
    "The given group does not exist" : "输入的群组不存在",
    "Check %s is invalid or does not exist" : "检查%s是不可用或者不存在",
    "Operation #%s does not exist" : "操作 %s 不存在",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 %s 无效",
    "Check %s does not exist" : "检查%s不存在",
    "Check %s is invalid" : "检查%s是不可用",
    "Check #%s does not exist" : "检查#%s是不存在",
    "Workflow" : "数据流",
    "Open documentation" : "打开文档",
    "Add rule group" : "添加规则组",
    "Short rule description" : "短规则说明",
    "Add rule" : "添加规则",
    "Reset" : "重置",
    "Save" : "保存",
    "Saving…" : "保存中...",
    "Loading…" : "加载中",
    "Successfully saved" : "保存成功",
    "File mime type" : "文件MIME类型"
},
"nplurals=1; plural=0;");
